@@ -155,6 +155,12 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 										       detected to be the source in a shell pipe. */
 #define PPM_CL_PIPE_DST (1 << 22)			/* libsinsp-specific flag. Set if this thread has been 
 										       detected to be the destination in a shell pipe. */
+#define PPM_CL_CLONE_CHILD_CLEARTID (1 << 23)
+#define PPM_CL_CLONE_CHILD_SETTID (1 << 24)
+#define PPM_CL_CLONE_SETTLS (1 << 25)
+#define PPM_CL_CLONE_STOPPED (1 << 26)
+#define PPM_CL_CLONE_VFORK (1 << 27)
+#define PPM_CL_CLONE_NEWCGROUP (1 << 28)
 
 /*
  * Futex Operations
@@ -470,6 +476,18 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 #define PPM_W_OK            (1 << 1)
 #define PPM_R_OK            (1 << 2)
 
+/*
+ * Page fault flags
+ */
+#define PPM_PF_PROTECTION_VIOLATION	(1 << 0)
+#define PPM_PF_PAGE_NOT_PRESENT		(1 << 1)
+#define PPM_PF_WRITE_ACCESS		(1 << 2)
+#define PPM_PF_READ_ACCESS		(1 << 3)
+#define PPM_PF_USER_FAULT		(1 << 4)
+#define PPM_PF_SUPERVISOR_FAULT		(1 << 5)
+#define PPM_PF_RESERVED_PAGE		(1 << 6)
+#define PPM_PF_INSTRUCTION_FETCH	(1 << 7)
+
 /*
  * SuS says limits have to be unsigned.
  * Which makes a ton more sense anyway.
@@ -487,7 +505,6 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 # define _STK_LIM_MAX           RLIM_INFINITY
 #endif
 
-
 /*
  * The list of event types
  * Enter events have even numbers while exit events have odd numbers.
@@ -507,6 +524,7 @@ enum ppm_capture_category {
 	PPMC_SYSCALL = 1,
 	PPMC_CONTEXT_SWITCH = 2,
 	PPMC_SIGNAL = 3,
+	PPMC_PAGE_FAULT = 4,
 };
 
 /** @defgroup etypes Event Types
@@ -800,7 +818,13 @@ enum ppm_event_type {
 	PPME_SYSCALL_EXECVE_17_X = 283,
 	PPME_SYSCALL_UNSHARE_E = 284,
 	PPME_SYSCALL_UNSHARE_X = 285,
-	PPM_EVENT_MAX = 286
+	PPME_INFRASTRUCTURE_EVENT_E = 286,
+	PPME_INFRASTRUCTURE_EVENT_X = 287,
+	PPME_SYSCALL_EXECVE_18_E = 288,
+	PPME_SYSCALL_EXECVE_18_X = 289,
+	PPME_PAGE_FAULT_E = 290,
+	PPME_PAGE_FAULT_X = 291,
+	PPM_EVENT_MAX = 292
 };
 /*@}*/
 
@@ -990,7 +1014,7 @@ enum ppm_syscall_code {
 	PPM_SC_TGKILL = 179,
 	PPM_SC_UTIMES = 180,
 	PPM_SC_MQ_OPEN = 181,
-	PPM_SC_MQ_UNLINK = 18,
+	PPM_SC_MQ_UNLINK = 182,
 	PPM_SC_MQ_TIMEDSEND = 183,
 	PPM_SC_MQ_TIMEDRECEIVE = 184,
 	PPM_SC_MQ_NOTIFY = 185,
@@ -1300,7 +1324,9 @@ struct ppm_evt_hdr {
 #define PPM_IOCTL_ENABLE_SIGNAL_DELIVER _IO(PPM_IOCTL_MAGIC, 15)
 #define PPM_IOCTL_GET_PROCLIST _IO(PPM_IOCTL_MAGIC, 16)
 #define PPM_IOCTL_SET_TRACERS_CAPTURE _IO(PPM_IOCTL_MAGIC, 17)
-
+#define PPM_IOCTL_SET_SIMPLE_MODE _IO(PPM_IOCTL_MAGIC, 18)
+#define PPM_IOCTL_ENABLE_PAGE_FAULTS _IO(PPM_IOCTL_MAGIC, 19)
+#define PPM_IOCTL_GET_N_TRACEPOINT_HIT _IO(PPM_IOCTL_MAGIC, 20)
 
 extern const struct ppm_name_value socket_families[];
 extern const struct ppm_name_value file_flags[];
@@ -1326,7 +1352,7 @@ extern const struct ppm_name_value semop_flags[];
 extern const struct ppm_name_value semget_flags[];
 extern const struct ppm_name_value semctl_commands[];
 extern const struct ppm_name_value access_flags[];
-
+extern const struct ppm_name_value pf_flags[];
 
 extern const struct ppm_param_info ptrace_dynamic_param[];
 
