@@ -112,6 +112,12 @@ const struct ppm_name_value clone_flags[] = {
 	{"NAME_CHANGED", PPM_CL_NAME_CHANGED},
 	{"CLOSED", PPM_CL_CLOSED},
 	{"CLONE_NEWUSER", PPM_CL_CLONE_NEWUSER},
+	{"CLONE_CHILD_CLEARTID", PPM_CL_CLONE_CHILD_CLEARTID},
+	{"CLONE_CHILD_SETTID", PPM_CL_CLONE_CHILD_SETTID},
+	{"CLONE_SETTLS", PPM_CL_CLONE_SETTLS},
+	{"CLONE_STOPPED", PPM_CL_CLONE_STOPPED},
+	{"CLONE_VFORK", PPM_CL_CLONE_VFORK},
+	{"CLONE_NEWCGROUP", PPM_CL_CLONE_NEWCGROUP},
 	{0, 0},
 };
 
@@ -417,3 +423,15 @@ const struct ppm_name_value access_flags[] = {
 	{"X_OK", PPM_X_OK},
 	{0, 0},
 };
+
+const struct ppm_name_value pf_flags[] = {
+	{"PROTECTION_VIOLATION", PPM_PF_PROTECTION_VIOLATION},
+	{"PAGE_NOT_PRESENT", PPM_PF_PAGE_NOT_PRESENT},
+	{"WRITE_ACCESS", PPM_PF_WRITE_ACCESS},
+	{"READ_ACCESS", PPM_PF_READ_ACCESS},
+	{"USER_FAULT", PPM_PF_USER_FAULT},
+	{"SUPERVISOR_FAULT", PPM_PF_SUPERVISOR_FAULT},
+	{"RESERVED_PAGE", PPM_PF_RESERVED_PAGE},
+	{"INSTRUCTION_FETCH", PPM_PF_INSTRUCTION_FETCH},
+	{0, 0},
+};
