@@ -235,8 +235,8 @@ int32_t scap_proc_fill_info_from_stats(char* procdirname, struct scap_threadinfo
 	if(sscanf(s + 2, "%c %" PRId64 " %" PRId64 " %" PRId64 " %" PRId32 " %" PRId64 " %" PRId64 " %" PRId64 " %" PRId64 " %" PRId64,
 		&tmpc,
 		&tmp,
-		&sid,
 		&tmp,
+		&sid,
 		&tty,
 		&tmp,
 		&tmp,
@@ -469,7 +469,7 @@ int32_t scap_proc_fill_root(struct scap_threadinfo* tinfo, const char* procdirna
 static int32_t scap_proc_add_from_proc(scap_t* handle, uint32_t tid, int parenttid, int tid_to_scan, char* procdirname, struct scap_ns_socket_list** sockets_by_ns, scap_threadinfo** procinfo, char *error)
 {
 	char dir_name[256];
-	char target_name[256];
+	char target_name[SCAP_MAX_PATH_SIZE];
 	int target_res;
 	char filename[252];
 	char line[SCAP_MAX_ENV_SIZE];
@@ -516,20 +516,24 @@ static int32_t scap_proc_add_from_proc(scap_t* handle, uint32_t tid, int parentt
 		{
 			fclose(f);
 		}
+
+		target_name[0] = 0;
+	}
+	else
+	{
+		// null-terminate target_name (readlink() does not append a null byte)
+		target_name[target_res] = 0;
 	}
 
 	//
 	// This is a real user level process. Allocate the procinfo structure.
 	//
-	tinfo = (scap_threadinfo*)malloc(sizeof(scap_threadinfo));
-	if(tinfo == NULL)
+	if((tinfo = scap_proc_alloc(handle)) == NULL)
 	{
-		snprintf(error, SCAP_LASTERR_SIZE, "process table allocation error (1)");
+		// Error message saved in handle->m_lasterr
 		return SCAP_FAILURE;
 	}
 
-	memset(tinfo, 0, sizeof(scap_threadinfo));
-
 	tinfo->tid = tid;
 	if(parenttid != -1)
 	{
@@ -557,6 +561,11 @@ static int32_t scap_proc_add_from_proc(scap_t* handle, uint32_t tid, int parentt
 		tinfo->flags = PPM_CL_CLONE_THREAD | PPM_CL_CLONE_FILES;
 	}
 
+	//
+	// Gathers the exepath
+	//
+	snprintf(tinfo->exepath, sizeof(tinfo->exepath), "%s", target_name);
+
 	//
 	// Gather the command name
 	//
@@ -1045,6 +1054,18 @@ void scap_refresh_proc_table(scap_t* handle)
 }
 #endif // HAS_CAPTURE
 
+struct scap_threadinfo *scap_proc_alloc(scap_t *handle)
+{
+	struct scap_threadinfo *tinfo = (struct scap_threadinfo*) calloc(1, sizeof(scap_threadinfo));
+	if(tinfo == NULL)
+	{
+		snprintf(handle->m_lasterr, SCAP_LASTERR_SIZE, "process table allocation error (1)");
+		return NULL;
+	}
+
+	return tinfo;
+}
+
 void scap_proc_free(scap_t* handle, struct scap_threadinfo* proc)
 {
 	scap_fd_free_proc_fd_table(handle, proc);
