@@ -27,6 +27,7 @@ sinsp_dumper::sinsp_dumper(sinsp* inspector)
 	m_dumper = NULL;
 	m_target_memory_buffer = NULL;
 	m_target_memory_buffer_size = 0;
+	m_nevts = 0;
 }
 
 sinsp_dumper::sinsp_dumper(sinsp* inspector, uint8_t* target_memory_buffer, uint64_t target_memory_buffer_size)
@@ -52,11 +53,6 @@ void sinsp_dumper::open(const string& filename, bool compress, bool threads_from
 		throw sinsp_exception("can't start event dump, inspector not opened yet");
 	}
 
-	if(threads_from_sinsp)
-	{
-		m_inspector->m_thread_manager->to_scap();
-	}
-
 	if(m_target_memory_buffer)
 	{
 		m_dumper = scap_memory_dump_open(m_inspector->m_h, m_target_memory_buffer, m_target_memory_buffer_size);
@@ -78,7 +74,45 @@ void sinsp_dumper::open(const string& filename, bool compress, bool threads_from
 		throw sinsp_exception(scap_getlasterr(m_inspector->m_h));
 	}
 
+	if(threads_from_sinsp)
+	{
+		m_inspector->m_thread_manager->dump_threads_to_file(m_dumper);
+	}
+
 	m_inspector->m_container_manager.dump_containers(m_dumper);
+
+	m_nevts = 0;
+}
+
+void sinsp_dumper::fdopen(int fd, bool compress, bool threads_from_sinsp)
+{
+	if(m_inspector->m_h == NULL)
+	{
+		throw sinsp_exception("can't start event dump, inspector not opened yet");
+	}
+
+	if(compress)
+	{
+		m_dumper = scap_dump_open_fd(m_inspector->m_h, fd, SCAP_COMPRESSION_GZIP, true);
+	}
+	else
+	{
+		m_dumper = scap_dump_open_fd(m_inspector->m_h, fd, SCAP_COMPRESSION_NONE, true);
+	}
+
+	if(m_dumper == NULL)
+	{
+		throw sinsp_exception(scap_getlasterr(m_inspector->m_h));
+	}
+
+	if(threads_from_sinsp)
+	{
+		m_inspector->m_thread_manager->dump_threads_to_file(m_dumper);
+	}
+
+	m_inspector->m_container_manager.dump_containers(m_dumper);
+
+	m_nevts = 0;
 }
 
 void sinsp_dumper::close()
@@ -90,6 +124,16 @@ void sinsp_dumper::close()
 	}
 }
 
+bool sinsp_dumper::is_open()
+{
+	return (m_dumper != NULL);
+}
+
+bool sinsp_dumper::written_events()
+{
+	return m_nevts;
+}
+
 void sinsp_dumper::dump(sinsp_evt* evt)
 {
 	if(m_dumper == NULL)
@@ -106,6 +150,8 @@ void sinsp_dumper::dump(sinsp_evt* evt)
 	{
 		throw sinsp_exception(scap_getlasterr(m_inspector->m_h));
 	}
+
+	m_nevts++;
 }
 
 uint64_t sinsp_dumper::written_bytes()
@@ -124,6 +170,22 @@ uint64_t sinsp_dumper::written_bytes()
 	return written_bytes;
 }
 
+uint64_t sinsp_dumper::next_write_position()
+{
+	if(m_dumper == NULL)
+	{
+		return 0;
+	}
+
+	int64_t position = scap_dump_ftell(m_dumper);
+	if(position == -1)
+	{
+		throw sinsp_exception("error getting offset");
+	}
+
+	return position;
+}
+
 void sinsp_dumper::flush()
 {
 	if(m_dumper == NULL)
