@@ -42,6 +42,7 @@ class sinsp_protodecoder;
 #define CHAR_FD_EVENTPOLL		'l'
 #define CHAR_FD_INOTIFY			'i'
 #define CHAR_FD_TIMERFD			't'
+#define CHAR_FD_NETLINK			'n'
 
 /** @defgroup state State management 
  * A collection of classes to query process and FD state.
@@ -218,7 +219,7 @@ public:
 	*/
 	bool is_file()
 	{
-		return m_type == SCAP_FD_FILE;
+		return m_type == SCAP_FD_FILE || m_type == SCAP_FD_FILE_V2;
 	}
 
 	/*!
@@ -323,6 +324,9 @@ private:
 		FLAGS_IS_TRACER_FILE = (1 << 7),
 		FLAGS_IS_TRACER_FD = (1 << 8),
 		FLAGS_IS_NOT_TRACER_FD = (1 << 9),
+		FLAGS_IN_BASELINE_R = (1 << 10),
+		FLAGS_IN_BASELINE_RW = (1 << 11),
+		FLAGS_IN_BASELINE_OTHER = (1 << 12),
 	};
 
 	void add_filename(const char* fullpath);
@@ -367,6 +371,43 @@ private:
 		return !is_role_client() && !is_role_server();
 	}
 
+	inline void set_inpipeline_r()
+	{
+		m_flags |= FLAGS_IN_BASELINE_R;
+	}
+
+	inline void set_inpipeline_rw()
+	{
+		m_flags |= FLAGS_IN_BASELINE_RW;
+	}
+
+	inline void set_inpipeline_other()
+	{
+		m_flags |= FLAGS_IN_BASELINE_OTHER;
+	}
+
+	inline void reset_inpipeline()
+	{
+		m_flags &= ~FLAGS_IN_BASELINE_R;
+		m_flags &= ~FLAGS_IN_BASELINE_RW;
+		m_flags &= ~FLAGS_IN_BASELINE_OTHER;
+	}
+
+	inline bool is_inpipeline_r()
+	{
+		return (m_flags & FLAGS_IN_BASELINE_R) == FLAGS_IN_BASELINE_R; 
+	}
+
+	inline bool is_inpipeline_rw()
+	{
+		return (m_flags & FLAGS_IN_BASELINE_RW) == FLAGS_IN_BASELINE_RW; 
+	}
+
+	inline bool is_inpipeline_other()
+	{
+		return (m_flags & FLAGS_IN_BASELINE_OTHER) == FLAGS_IN_BASELINE_OTHER; 
+	}
+
 	T* m_usrstate;
 	uint32_t m_flags;
 	uint64_t m_ino;
@@ -384,6 +425,7 @@ private:
 	friend class sinsp_filter_check_event;
 	friend class lua_cbacks;
 	friend class sinsp_proto_detector;
+	friend class sinsp_baseliner;
 };
 
 /*@}*/
