@@ -1708,7 +1708,16 @@ void sinsp_filter_compiler::parse_check()
 	{
 		if(!(chk->get_fields()->m_flags & filter_check_info::FL_WORKS_ON_THREAD_TABLE))
 		{
-			throw sinsp_exception("the given filter is not supported for thread table filtering");
+			if(str_operand1 != "evt.rawtime" && 
+				str_operand1 != "evt.rawtime.s" && 
+				str_operand1 != "evt.rawtime.ns" && 
+				str_operand1 != "evt.time" && 
+				str_operand1 != "evt.time.s" && 
+				str_operand1 != "evt.datetime" && 
+				str_operand1 != "evt.reltime")
+			{
+				throw sinsp_exception("the given filter is not supported for thread table filtering");
+			}
 		}
 	}
 
@@ -1803,7 +1812,6 @@ void sinsp_filter_compiler::parse_check()
 			//
 			// Create the 'or' sequence
 			//
-			uint32_t num_values = 0;
 			while(true)
 			{
 				// 'in' clause aware
@@ -1815,8 +1823,7 @@ void sinsp_filter_compiler::parse_check()
 				sinsp_filter_check* newchk = g_filterlist.new_filter_check_from_another(chk);
 				newchk->m_boolop = op;
 				newchk->m_cmpop = CO_EQ;
-				newchk->add_filter_value((char *)&operand2[0], (uint32_t)operand2.size() - 1, num_values);
-				num_values++;
+				newchk->add_filter_value((char *)&operand2[0], (uint32_t)operand2.size() - 1);
 
 				m_filter->add_check(newchk);
 
