@@ -98,8 +98,8 @@ public:
 	virtual const filtercheck_field_info* get_field_info();
 
 	//
-        // Extract the field from the event. In sanitize_strings is true, any
-        // string values are sanitized to remove nonprintable characters.
+	// Extract the field from the event. In sanitize_strings is true, any
+	// string values are sanitized to remove nonprintable characters.
 	//
 	virtual uint8_t* extract(sinsp_evt *evt, OUT uint32_t* len, bool sanitize_strings = true) = 0;
 
@@ -321,7 +321,7 @@ private:
 };
 
 //
-// thread sinsp_filter_check_syslog
+// thread sinsp_filter_check_thread
 //
 class sinsp_filter_check_thread : public sinsp_filter_check
 {
@@ -371,6 +371,8 @@ public:
 		TYPE_SID = 40,
 		TYPE_SNAME = 41,
 		TYPE_TTY = 42,
+		TYPE_EXEPATH = 43,
+		TYPE_NAMETID = 44,
 	};
 
 	sinsp_filter_check_thread();
@@ -467,7 +469,11 @@ public:
 		TYPE_BUFLEN_NET_IN = 58,
 		TYPE_BUFLEN_NET_OUT = 59,
 		TYPE_ISOPEN_READ = 60,
-		TYPE_ISOPEN_WRITE = 61
+		TYPE_ISOPEN_WRITE = 61,
+		TYPE_INFRA_DOCKER_NAME = 62,
+		TYPE_INFRA_DOCKER_CONTAINER_ID = 63,
+		TYPE_INFRA_DOCKER_CONTAINER_NAME = 64,
+		TYPE_INFRA_DOCKER_CONTAINER_IMAGE = 65
 	};
 
 	sinsp_filter_check_event();
@@ -789,6 +795,7 @@ public:
 	int32_t parse_field_name(const char* str, bool alloc_state, bool needed_for_filtering);
 	uint8_t* extract(sinsp_evt *evt, OUT uint32_t* len, bool sanitize_strings = true);
 	char* tostring_nice(sinsp_evt* evt, uint32_t str_len, uint64_t time_delta);
+	Json::Value tojson(sinsp_evt* evt, uint32_t str_len, uint64_t time_delta);
 
 private:
 	inline char* format_bytes(double val, uint32_t str_len, bool is_int);
