@@ -16,7 +16,7 @@ class marathon_http : public mesos_http
 public:
 	typedef std::shared_ptr<marathon_http> ptr_t;
 
-	marathon_http(mesos& m, const uri& url, int timeout_ms = 5000L);
+	marathon_http(mesos& m, const uri& url, bool discover_marathon, int timeout_ms = 5000L, const string& token = "");
 
 	~marathon_http();
 
@@ -25,7 +25,7 @@ public:
 	std::string get_groups(const std::string& group_id);
 
 private:
-	std::string   m_data;
+	std::string m_data;
 };
 
 #endif // HAS_CAPTURE
