@@ -32,13 +32,14 @@ public:
 	void stop();
 
 	bool is_active() const;
+	bool is_healthy(int expected_count) const;
 
 	bool has(std::shared_ptr<mesos_http> handler);
 	bool remove(std::shared_ptr<mesos_http> handler);
 
 private:
 	void clear();
-	void remove(socket_map_t::iterator it);
+	socket_map_t::iterator& remove(socket_map_t::iterator& it);
 
 	socket_map_t     m_sockets;
 	fd_set           m_infd;
