@@ -364,6 +364,7 @@ void sinsp_threadinfo::init(scap_threadinfo* pi)
 
 	m_comm = pi->comm;
 	m_exe = pi->exe;
+	m_exepath = pi->exepath;
 	set_args(pi->args, pi->args_len);
 	if(is_main_thread())
 	{
@@ -462,6 +463,11 @@ string sinsp_threadinfo::get_exe()
 	return m_exe;
 }
 
+string sinsp_threadinfo::get_exepath()
+{
+	return m_exepath;
+}
+
 void sinsp_threadinfo::set_args(const char* args, size_t len)
 {
 	m_args.clear();
@@ -1365,6 +1371,7 @@ void sinsp_thread_manager::thread_to_scap(sinsp_threadinfo& tinfo, 	scap_threadi
 
 	strncpy(sctinfo->comm, tinfo.m_comm.c_str(), SCAP_MAX_PATH_SIZE);
 	strncpy(sctinfo->exe, tinfo.m_exe.c_str(), SCAP_MAX_PATH_SIZE);
+	strncpy(sctinfo->exepath, tinfo.m_exepath.c_str(), SCAP_MAX_PATH_SIZE);
 	tinfo.args_to_scap(sctinfo);
 	tinfo.env_to_scap(sctinfo);
 	string tcwd = (tinfo.m_cwd == "")? "/": tinfo.m_cwd;
@@ -1388,8 +1395,6 @@ void sinsp_thread_manager::thread_to_scap(sinsp_threadinfo& tinfo, 	scap_threadi
 
 void sinsp_thread_manager::dump_threads_to_file(scap_dumper_t* dumper)
 {
-	scap_threadinfo sctinfo;
-
 	//
 	// First pass of the table to calculate the length
 	//
@@ -1397,11 +1402,18 @@ void sinsp_thread_manager::dump_threads_to_file(scap_dumper_t* dumper)
 
 	for(auto it = m_threadtable.begin(); it != m_threadtable.end(); ++it)
 	{
+		scap_threadinfo *sctinfo;
+
+		if((sctinfo = scap_proc_alloc(m_inspector->m_h)) == NULL)
+		{
+			throw sinsp_exception(scap_getlasterr(m_inspector->m_h));
+		}
+
 		sinsp_threadinfo& tinfo = it->second;
 
-		tinfo.args_to_scap(&sctinfo);
-		tinfo.env_to_scap(&sctinfo);
-		tinfo.cgroups_to_scap(&sctinfo);
+		tinfo.args_to_scap(sctinfo);
+		tinfo.env_to_scap(sctinfo);
+		tinfo.cgroups_to_scap(sctinfo);
 
 		string tcwd = (tinfo.m_cwd == "")? "/": tinfo.m_cwd;
 
@@ -1412,7 +1424,8 @@ void sinsp_thread_manager::dump_threads_to_file(scap_dumper_t* dumper)
 			sizeof(uint64_t) +	// sid
 			2 + MIN(tinfo.m_comm.size(), SCAP_MAX_PATH_SIZE) +
 			2 + MIN(tinfo.m_exe.size(), SCAP_MAX_PATH_SIZE) +
-			2 + sctinfo.args_len +
+			2 + MIN(tinfo.m_exepath.size(), SCAP_MAX_PATH_SIZE) +
+			2 + sctinfo->args_len +
 			2 + MIN(tcwd.size(), SCAP_MAX_PATH_SIZE) +
 			sizeof(uint64_t) +	// fdlimit
 			sizeof(uint32_t) +	// uid
@@ -1422,14 +1435,16 @@ void sinsp_thread_manager::dump_threads_to_file(scap_dumper_t* dumper)
 			sizeof(uint32_t) +  // vmswap_kb
 			sizeof(uint64_t) +  // pfmajor
 			sizeof(uint64_t) +  // pfminor
-			2 + sctinfo.env_len +
+			2 + sctinfo->env_len +
 			sizeof(int64_t) +  // vtid
 			sizeof(int64_t) +  // vpid
-			2 + sctinfo.cgroups_len +
+			2 + sctinfo->cgroups_len +
 			sizeof(uint32_t) +
 			2 + MIN(tinfo.m_root.size(), SCAP_MAX_PATH_SIZE));
 
 		totlen += il;
+
+		scap_proc_free(m_inspector->m_h, sctinfo);
 	}
 
 	//
@@ -1442,14 +1457,22 @@ void sinsp_thread_manager::dump_threads_to_file(scap_dumper_t* dumper)
 
 	for(auto it = m_threadtable.begin(); it != m_threadtable.end(); ++it)
 	{
-		sinsp_threadinfo& tinfo = it->second;
+		scap_threadinfo *sctinfo;
 
-		thread_to_scap(tinfo, &sctinfo);
-
-		if(scap_write_proclist_entry(m_inspector->m_h, dumper, &sctinfo) != SCAP_SUCCESS)
+		if((sctinfo = scap_proc_alloc(m_inspector->m_h)) == NULL)
 		{
 			throw sinsp_exception(scap_getlasterr(m_inspector->m_h));
 		}
+		sinsp_threadinfo& tinfo = it->second;
+
+		thread_to_scap(tinfo, sctinfo);
+
+		if(scap_write_proclist_entry(m_inspector->m_h, dumper, sctinfo) != SCAP_SUCCESS)
+		{
+			throw sinsp_exception(scap_getlasterr(m_inspector->m_h));
+		}
+
+		scap_proc_free(m_inspector->m_h, sctinfo);
 	}
 
 	if(scap_write_proclist_trailer(m_inspector->m_h, dumper, totlen) != SCAP_SUCCESS)
@@ -1460,16 +1483,19 @@ void sinsp_thread_manager::dump_threads_to_file(scap_dumper_t* dumper)
 	//
 	// Third pass of the table to dump the FDs
 	//
-	vector<scap_fdinfo*>* fdinfos_to_free = new vector<scap_fdinfo*>();
 
 	for(auto it = m_threadtable.begin(); it != m_threadtable.end(); ++it)
 	{
+		scap_threadinfo *sctinfo;
+
+		if((sctinfo = scap_proc_alloc(m_inspector->m_h)) == NULL)
+		{
+			throw sinsp_exception(scap_getlasterr(m_inspector->m_h));
+		}
+
 		sinsp_threadinfo& tinfo = it->second;
 
-		thread_to_scap(tinfo, &sctinfo);
-
-		fdinfos_to_free->clear();
-
+		thread_to_scap(tinfo, sctinfo);
 
 		if(tinfo.is_main_thread())
 		{
@@ -1485,13 +1511,10 @@ void sinsp_thread_manager::dump_threads_to_file(scap_dumper_t* dumper)
 				scap_fdinfo* scfdinfo = (scap_fdinfo*)malloc(sizeof(scap_fdinfo));
 				if(scfdinfo == NULL)
 				{
-					free_dump_fdinfos(fdinfos_to_free);
-					delete fdinfos_to_free;
+					scap_proc_free(m_inspector->m_h, sctinfo);
 					throw sinsp_exception("thread memory allocation error in sinsp_thread_manager::to_scap");
 				}
 
-				fdinfos_to_free->push_back(scfdinfo);
-
 				//
 				// Populate the fd info
 				//
@@ -1501,10 +1524,9 @@ void sinsp_thread_manager::dump_threads_to_file(scap_dumper_t* dumper)
 				//
 				// Add the new fd to the scap table
 				//
-				if(scap_fd_add(&sctinfo, it->first, scfdinfo) != SCAP_SUCCESS)
+				if(scap_fd_add(sctinfo, it->first, scfdinfo) != SCAP_SUCCESS)
 				{
-					free_dump_fdinfos(fdinfos_to_free);
-					delete fdinfos_to_free;
+					scap_proc_free(m_inspector->m_h, sctinfo);
 					throw sinsp_exception("error calling scap_fd_add in sinsp_thread_manager::to_scap");
 				}
 			}
@@ -1513,16 +1535,12 @@ void sinsp_thread_manager::dump_threads_to_file(scap_dumper_t* dumper)
 		//
 		// Dump the thread to disk
 		//
-		if(scap_write_proc_fds(m_inspector->m_h, &sctinfo, dumper) != SCAP_SUCCESS)
+		if(scap_write_proc_fds(m_inspector->m_h, sctinfo, dumper) != SCAP_SUCCESS)
 		{
-			free_dump_fdinfos(fdinfos_to_free);
-			delete fdinfos_to_free;
+			scap_proc_free(m_inspector->m_h, sctinfo);
 			throw sinsp_exception("error calling scap_proc_add in sinsp_thread_manager::to_scap");
 		}
 
-		free_dump_fdinfos(fdinfos_to_free);
+		scap_proc_free(m_inspector->m_h, sctinfo);
 	}
-
-	free_dump_fdinfos(fdinfos_to_free);
-	delete fdinfos_to_free;
 }
