@@ -68,10 +68,15 @@ public:
 	string get_comm();
 
 	/*!
-	  \brief Return the full name of the process containing this thread, e.g. "/bin/top".
+	  \brief Return the name of the process containing this thread from argv[0], e.g. "/bin/top".
 	*/
 	string get_exe();
 
+	/*!
+	  \brief Return the full executable path of the process containing this thread, e.g. "/bin/top".
+	*/
+	string get_exepath();
+
 	/*!
 	  \brief Return the working directory of the process containing this thread.
 	*/
@@ -215,6 +220,7 @@ public:
 	int64_t m_sid; ///< The session id of the process containing this thread.
 	string m_comm; ///< Command name (e.g. "top")
 	string m_exe; ///< argv[0] (e.g. "sshd: user@pts/4")
+	string m_exepath; ///< full executable path
 	vector<string> m_args; ///< Command line arguments (e.g. "-d1")
 	vector<string> m_env; ///< Environment variables
 	vector<pair<string, string>> m_cgroups; ///< subsystem-cgroup pairs
