@@ -267,3 +267,19 @@ function concattable(dst, src)
     
     return dst
 end
+
+--[[
+return the type of a variable.
+]]--
+function typeof(var)
+    local _type = type(var);
+    if(_type ~= "table" and _type ~= "userdata") then
+        return _type;
+    end
+    local _meta = getmetatable(var);
+    if(_meta ~= nil and _meta._NAME ~= nil) then
+        return _meta._NAME;
+    else
+        return _type;
+    end
+end
