@@ -1,11 +1,10 @@
 --[[
 Copyright (C) 2013-2014 Draios inc.
- 
+
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License version 2 as
 published by the Free Software Foundation.
 
-
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -16,7 +15,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 --]]
 
 -- Chisel description
-description = "Shows the top processes in terms of system call errors."
+description = "Shows the top processes in terms of system call errors. This chisel is compatible with containers using the sysdig -pc or -pcontainer argument, otherwise no container information will be shown."
 short_description = "top processes by number of errors"
 category = "Errors"
 
@@ -30,13 +29,29 @@ end
 
 -- Initialization callback
 function on_init()
-	chisel.exec("table_generator", 
-		"proc.name",
-		"Process",
-		"evt.count",
-		"#Errors",
-		"evt.failed=true", 
-		"100",
-		"none")
+
+	-- The -pc or -pcontainer options was supplied on the cmd line
+	print_container = sysdig.is_print_container_data()
+
+	if print_container then
+		chisel.exec("table_generator",
+					"proc.name,proc.pid,thread.vtid,container.name",
+					"Process,Host_pid,Container_pid,container.name",
+					"evt.count",
+					"#Errors",
+					"evt.failed=true",
+					"100",
+					"none")
+	else
+		chisel.exec("table_generator",
+					"proc.name,proc.pid",
+					"Process,PID",
+					"evt.count",
+					"#Errors",
+					"evt.failed=true",
+					"100",
+					"none")
+	end
+
 	return true
 end
