@@ -21,9 +21,9 @@ view_info =
 	name = "Connections",
 	description = "Top network connections. This view lists all of the network connections that were active during the last sampling interval, with details for each of them.",
 	tips = {"This view can be applied not only to the whole machine, but also to single processes, containers, threads and so on. Use it after a drill down for more fine grained investigation."},
-	tags = {"Default"},
+	tags = {"Default", "wsysdig"},
 	view_type = "table",
-	applies_to = {"", "container.id", "proc.pid", "proc.name", "thread.tid", "fd.sport", "fd.sproto", "fd.dport", "fd.dproto", "fd.port", "fd.proto", "fd.lport", "fd.rport", "evt.res", "k8s.pod.id", "k8s.rc.id", "k8s.rs.id", "k8s.svc.id", "k8s.ns.id", "marathon.app.id", "marathon.group.name", "mesos.task.id", "mesos.framework.name"},
+	applies_to = {"", "container.id", "proc.pid", "thread.nametid", "proc.name", "thread.tid", "fd.sport", "fd.sproto", "fd.dport", "fd.dproto", "fd.port", "fd.proto", "fd.lport", "fd.rport", "evt.res", "k8s.pod.id", "k8s.rc.id", "k8s.rs.id", "k8s.svc.id", "k8s.ns.id", "marathon.app.id", "marathon.group.name", "mesos.task.id", "mesos.framework.name"},
 	filter = "fd.type=ipv4 or fd.type=ipv6 and fd.name!=''",
 	use_defaults = true,
 	drilldown_target = "incoming_connections",
@@ -71,12 +71,6 @@ view_info =
 			field = "fd.rport",
 			colsize = 8,
 		},
-		{
-			name = "PROTO",
-			description = "Connection protocol, obtained by resolving the server port name.",
-			field = "fd.sproto",
-			colsize = 8,
-		},
 		{
 			is_sorting = true,
 			name = "BPS IN",
