@@ -22,7 +22,7 @@ view_info =
 	description = "List every newly established network connection.",
 	tags = {"Default"},
 	view_type = "list",
-	applies_to = {"", "container.id", "proc.pid", "thread.tid", "proc.name", "fd.name", "fd.containername", "fd.sport", "fd.sproto", "fd.dport", "fd.port", "fd.lport", "fd.rport", "k8s.pod.id", "k8s.rc.id", "k8s.rs.id", "k8s.svc.id", "k8s.ns.id", "marathon.app.id", "marathon.group.name", "mesos.task.id", "mesos.framework.name"},
+	applies_to = {"", "container.id", "proc.pid", "thread.nametid", "thread.tid", "proc.name", "fd.name", "fd.containername", "fd.sport", "fd.sproto", "fd.dport", "fd.port", "fd.lport", "fd.rport", "k8s.pod.id", "k8s.rc.id", "k8s.rs.id", "k8s.svc.id", "k8s.ns.id", "marathon.app.id", "marathon.group.name", "mesos.task.id", "mesos.framework.name"},
 	filter = "evt.type=accept and evt.dir=< and evt.failed=false",
 	columns = 
 	{
@@ -42,14 +42,14 @@ view_info =
 			tags = {"containers"},
 			name = "Container",
 			field = "container.name",
-			description = "Name of the container. What this field contains depends on the containerization technology. For example, for docker this is the content of the 'NAMES' column in 'docker ps'",
+			description = "Name of the container. This field depends on the containerization technology. For docker this is the 'NAMES' column in 'docker ps'",
 			colsize = 20
 		},
 		{
 			name = "Command",
 			field = "proc.exeline",
 			aggregation = "MAX",
-			description = "Name and argyuments of the process that received the connection.",
+			description = "Name and arguments of the process that received the connection.",
 			colsize = 0
 		}		
 	}
