@@ -135,130 +135,6 @@ void list_fields(bool verbose, bool markdown)
 	}
 }
 
-const char* param_type_to_string(ppm_param_type pt)
-{
-	switch(pt)
-	{
-	case PT_NONE:
-		return "NONE";
-		break;
-	case PT_INT8:
-		return "INT8";
-		break;
-	case PT_INT16:
-		return "INT16";
-		break;
-	case PT_INT32:
-		return "INT32";
-		break;
-	case PT_INT64:
-		return "INT64";
-		break;
-	case PT_UINT8:
-		return "UINT8";
-		break;
-	case PT_UINT16:
-		return "UINT16";
-		break;
-	case PT_UINT32:
-		return "UINT32";
-		break;
-	case PT_UINT64:
-		return "UINT64";
-		break;
-	case PT_CHARBUF:
-		return "CHARBUF";
-		break;
-	case PT_BYTEBUF:
-		return "BYTEBUF";
-		break;
-	case PT_ERRNO:
-		return "ERRNO";
-		break;
-	case PT_SOCKADDR:
-		return "SOCKADDR";
-		break;
-	case PT_SOCKTUPLE:
-		return "SOCKTUPLE";
-		break;
-	case PT_FD:
-		return "FD";
-		break;
-	case PT_PID:
-		return "PID";
-		break;
-	case PT_FDLIST:
-		return "FDLIST";
-		break;
-	case PT_FSPATH:
-		return "FSPATH";
-		break;
-	case PT_SYSCALLID:
-		return "SYSCALLID";
-		break;
-	case PT_SIGTYPE:
-		return "SIGTYPE";
-		break;
-	case PT_RELTIME:
-		return "RELTIME";
-		break;
-	case PT_ABSTIME:
-		return "ABSTIME";
-		break;
-	case PT_PORT:
-		return "PORT";
-		break;
-	case PT_L4PROTO:
-		return "L4PROTO";
-		break;
-	case PT_SOCKFAMILY:
-		return "SOCKFAMILY";
-		break;
-	case PT_BOOL:
-		return "BOOL";
-		break;
-	case PT_IPV4ADDR:
-		return "IPV4ADDR";
-		break;
-	case PT_DYN:
-		return "DYNAMIC";
-		break;
-	case PT_FLAGS8:
-		return "FLAGS8";
-		break;
-	case PT_FLAGS16:
-		return "FLAGS16";
-		break;
-	case PT_FLAGS32:
-		return "FLAGS32";
-		break;
-	case PT_UID:
-		return "UID";
-		break;
-	case PT_GID:
-		return "GID";
-		break;
-	case PT_SIGSET:
-		return "SIGSET";
-		break;
-	case PT_IPV4NET:
-		return "IPV4NET";
-		break;
-	case PT_DOUBLE:
-		return "DOUBLE";
-		break;
-	case PT_CHARBUFARRAY:
-		return "CHARBUFARRAY";
-		break;
-	case PT_CHARBUF_PAIR_ARRAY:
-		return "CHARBUF_PAIR_ARRAY";
-		break;
-	default:
-		ASSERT(false);
-		return "<NA>";
-	}
-}
-
 void list_events(sinsp* inspector)
 {
 	uint32_t j, k;
